@@ -65,7 +65,7 @@ require AutoLoader;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-our $VERSION = '2.23';
+our $VERSION = '2.24';
 
 
 bootstrap Math::GMP $VERSION;
@@ -118,7 +118,7 @@ Math::GMP - High speed arbitrary size integer math
 
 =head1 VERSION
 
-version 2.23
+version 2.24
 
 =head1 SYNOPSIS
 
@@ -212,7 +212,8 @@ Calculates the factorial of $x and returns the result.
   my $val = $x->bnok(2);      # 1*2*3*4*5/(1*2)/(1*2*3) = 10
   print $val;
 
-Calculates the binomial of $n over $k and returns the result.
+Calculates the binomial coefficient of $n over $k and returns the result.
+Equals to $n!/($k!*($n-$k)!).
 
 ( Added in version 2.23 .)
 
